/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: rulenameedit.h 94 2004-11-21 09:36:38Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AQBANKING_KDE_RULENAMEEDIT_H
#define AQBANKING_KDE_RULENAMEEDIT_H

class KBanking;


#include "rulenameedit.ui.h"

#include <gwenhywfar/db.h>


class RuleNameEdit: public RuleNameEditUI {
  Q_OBJECT
private:

public:
  RuleNameEdit(const QString &title,
               const char *name=0,
               const char *shortDescr=0,
               QWidget* parent=0,
               const char* wname=0,
               bool modal=FALSE,
               WFlags fl=0);
  ~RuleNameEdit();

  QString getName();
  QString getShortDescription();

private slots:
  void slotNameChanged(const QString &qs);

};


#endif


